@@ -1,7 +1,7 @@
 package Module::FatPack;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-10-03'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -209,11 +209,11 @@ Module::FatPack - Generate source code that contains fatpacked modules
 
 =head1 VERSION
 
-This document describes version 0.08 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-09-03.
+This document describes version 0.09 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-10-03.
 
 =head1 SEE ALSO
 
-L<App::FatPack>, L<App::fatten>
+L<App::FatPack>, L<App::depak>
 
 L<fatpack-modules>, CLI for C<fatpack_modules>
 
